@@ -36,18 +36,16 @@ def accuracy_score(Y,Y_pred):
     ------------------
     accuracy --- float
     """
-    
     if Y.T.shape == Y_pred.shape:
+        print(2)
         Y = Y.T
-        
+
     if Y.ndim == 2:
         Y = np.squeeze(Y) # now Y ndim = 1
-    elif Y_pred.ndim == 2:
+    if Y_pred.ndim == 2:
         Y_pred = np.squeeze(Y_pred) # in case, the user swap the position of input between y_pred and y
     
-    
     arr = Y == Y_pred
     arr_ = np.count_nonzero(arr) / len(arr)
-    
     return arr_
 
